@@ -1,7 +1,7 @@
 from .core.STDataset import STDataset
 from .run import run
 
-from .core.io import load_10X, load_anndata_h5
+from .core.io import load_10X, load_anndata_h5, load_table
 from . import filters, normalizers, plot
 
 from ._version import __version__
@@ -11,6 +11,7 @@ __all__ = [
     "run",
     "load_10X",
     "load_anndata_h5",
+    "load_table",
     "filters",
     "normalizers",
     "plot",
