@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from numpy import log as nlog
+from pandas import SparseDtype
 
 from .STDataset import STDataset
 
@@ -20,7 +21,8 @@ def cpm_normalizer(dataset: STDataset) -> STDataset:
         A STDataset instance with normalized expression matrix.
 
     """
-    scale_df = (dataset.count_df.T * 10000 / dataset.count_df.T.sum())
+    count_df = dataset.count_df.sparse.to_dense()
+    scale_df = (count_df.T * 10000 / count_df.T.sum())
     d = STDataset(
         scale_df.T,
         dataset.coordinate_df,
@@ -44,7 +46,8 @@ def logcpm_normalizer(dataset: STDataset) -> STDataset:
         A STDataset instance with normalized expression matrix.
 
     """
-    scale_df = nlog(dataset.count_df.T * 10000 / dataset.count_df.T.sum() + 1)
+    count_df = dataset.count_df.sparse.to_dense()
+    scale_df = nlog(count_df.T * 10000 / count_df.T.sum() + 1)
     d = STDataset(
         scale_df.T,
         dataset.coordinate_df,
